using System.Text.Json;
using System.Text.Json.Serialization;
using System.Threading;
using MediatR;
using Todo.Core.Interfaces.Publisher;

namespace Todo.Core.Application.Notifications.Todo;

public record TodoUpdated(
    [property: JsonPropertyName("todoId")] string TodoId) : INotification
{
    internal class Handler : INotificationHandler<TodoUpdated>
    {
        private readonly ITodoPublisher _todoPublisher;

        public Handler(ITodoPublisher todoPublisher) => _todoPublisher = todoPublisher;

        public async Task Handle(
            TodoUpdated notification,
            CancellationToken cancellationToken)
        {
            await _todoPublisher.Publish(
                "todoUpdated",
                JsonSerializer.Serialize(notification),
                cancellationToken);
        }
    }
}
